@@ -13,7 +13,7 @@ package Device::I2C::ADV7611;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -29,9 +29,11 @@ use constant CTRL_INFO => 0x3E;
 use constant CTRL_KSV  => 0x32;
 use constant CTRL_EDID => 0x36;
 use constant CTRL_CP   => 0x22;
+
 use Exporter qw(import);
 our @EXPORT_OK = qw(CTRL_IO CTRL_HDMI CTRL_DPLL CTRL_CEC
   CTRL_INFO CTRL_KSV CTRL_EDID CTRL_CP );
+our @ISA = qw(Device::I2C);
 
 sub new {
     my $class = shift;
@@ -59,7 +61,6 @@ sub resetDevice {
 sub checkCable {
     my ($io) = @_;
     return $io->readIO(0x6f) & 0x01;
-
 }
 
 sub writeRegister {
@@ -171,8 +172,8 @@ Device::I2C::ADV7611 - I2C interface to ADV7611 using Device::I2C
 <p>
 <img src="https://img.shields.io/badge/perl-5.10+-brightgreen.svg" alt="Requires Perl 5.10+" />
 <a href="https://travis-ci.org/shantanubhadoria/perl-Device-I2C-ADV7611"><img src="https://api.travis-ci.org/shantanubhadoria/perl-Device-I2C-ADV7611.svg?branch=build/master" alt="Travis status" /></a>
-<a href="http://matrix.cpantesters.org/?dist=Device-I2C-ADV7611%200.03"><img src="https://badgedepot.code301.com/badge/cpantesters/Device-I2C-ADV7611/0.03" alt="CPAN Testers result" /></a>
-<a href="http://cpants.cpanauthors.org/dist/Device-I2C-ADV7611-0.03"><img src="https://badgedepot.code301.com/badge/kwalitee/Device-I2C-ADV7611/0.03" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Device-I2C-ADV7611%200.04"><img src="https://badgedepot.code301.com/badge/cpantesters/Device-I2C-ADV7611/0.04" alt="CPAN Testers result" /></a>
+<a href="http://cpants.cpanauthors.org/dist/Device-I2C-ADV7611-0.04"><img src="https://badgedepot.code301.com/badge/kwalitee/Device-I2C-ADV7611/0.04" alt="Distribution kwalitee" /></a>
 <a href="https://gratipay.com/shantanubhadoria"><img src="https://img.shields.io/gratipay/shantanubhadoria.svg" alt="Gratipay" /></a>
 </p>
 
@@ -180,7 +181,7 @@ Device::I2C::ADV7611 - I2C interface to ADV7611 using Device::I2C
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
@@ -189,7 +190,7 @@ version 0.03
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests through github at 
-L<https://github.com/shantanubhadoria/perl-device-i2c-adv7611/issues>.
+L<https://github.com/sv99/perl-device-i2c-adv7611/issues>.
 You will be notified automatically of any progress on your issue.
 
 =head2 Source Code
@@ -197,9 +198,9 @@ You will be notified automatically of any progress on your issue.
 This is open source software.  The code repository is available for
 public review and contribution under the terms of the license.
 
-L<https://github.com/shantanubhadoria/perl-device-i2c-adv7611>
+L<https://github.com/sv99/perl-device-i2c-adv7611>
 
-  git clone git://github.com/shantanubhadoria/perl-device-i2c-adv7611.git
+  git clone git://github.com/sv99/perl-device-i2c-adv7611.git
 
 =head1 AUTHOR
 
